package org.apache.bcel.verifier;

import org.apache.bcel.Repository;
import org.apache.bcel.classfile.JavaClass;
import org.apache.bcel.classfile.Utility;

/* loaded from: org_apache_bcel_verifier.jar:org/apache/bcel/verifier/TransitiveHull.class */
public class TransitiveHull implements VerifierFactoryObserver {
    private int indent;

    public static void main(String[] args) {
        if (args.length != 1) {
            System.out.println("Need exactly one argument: The root class to verify.");
            System.exit(1);
        }
        int dotclasspos = args[0].lastIndexOf(".class");
        if (dotclasspos != -1) {
            args[0] = args[0].substring(0, dotclasspos);
        }
        args[0] = Utility.pathToPackage(args[0]);
        TransitiveHull th = new TransitiveHull();
        VerifierFactory.attach(th);
        VerifierFactory.getVerifier(args[0]);
        VerifierFactory.detach(th);
    }

    private TransitiveHull() {
    }

    @Override // org.apache.bcel.verifier.VerifierFactoryObserver
    public void update(String className) {
        System.gc();
        for (int i = 0; i < this.indent; i++) {
            System.out.print(" ");
        }
        System.out.println(className);
        this.indent++;
        Verifier v = VerifierFactory.getVerifier(className);
        VerificationResult vr = v.doPass1();
        if (vr != VerificationResult.VR_OK) {
            System.out.println("Pass 1:\n" + vr);
        }
        VerificationResult vr2 = v.doPass2();
        if (vr2 != VerificationResult.VR_OK) {
            System.out.println("Pass 2:\n" + vr2);
        }
        if (vr2 == VerificationResult.VR_OK) {
            try {
                JavaClass jc = Repository.lookupClass(v.getClassName());
                for (int i2 = 0; i2 < jc.getMethods().length; i2++) {
                    VerificationResult vr3 = v.doPass3a(i2);
                    if (vr3 != VerificationResult.VR_OK) {
                        System.out.println(v.getClassName() + ", Pass 3a, method " + i2 + " ['" + jc.getMethods()[i2] + "']:\n" + vr3);
                    }
                    VerificationResult vr4 = v.doPass3b(i2);
                    if (vr4 != VerificationResult.VR_OK) {
                        System.out.println(v.getClassName() + ", Pass 3b, method " + i2 + " ['" + jc.getMethods()[i2] + "']:\n" + vr4);
                    }
                }
            } catch (ClassNotFoundException e) {
                System.err.println("Could not find class " + v.getClassName() + " in Repository");
            }
        }
        this.indent--;
    }
}
